@@ -1,19 +1,21 @@
-//
-//   Copyright (C) 2003-2009 by Warren Woodford
-//   Heavily edited, with permision, by anticapitalista for antiX 2011-2014.
-//   Heavily revised by dolphin oracle, adrian, and anticaptialista 2018.
-//   Licensed under the Apache License, Version 2.0 (the "License");
-//   you may not use this file except in compliance with the License.
-//   You may obtain a copy of the License at
-//
-//       http://www.apache.org/licenses/LICENSE-2.0
-//
-//   Unless required by applicable law or agreed to in writing, software
-//   distributed under the License is distributed on an "AS IS" BASIS,
-//   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-//   See the License for the specific language governing permissions and
-//   limitations under the License.
-//
+/****************************************************************************
+ *  Copyright (C) 2003-2010 by Warren Woodford
+ *  Heavily edited, with permision, by anticapitalista for antiX 2011-2014.
+ *  Heavily revised by dolphin oracle, adrian, and anticaptialista 2018.
+ *  additional mount and compression oftions for btrfs by rob 2018
+ *  Major GUI update and user experience improvements by AK-47 2019.
+ *   Licensed under the Apache License, Version 2.0 (the "License");
+ *   you may not use this file except in compliance with the License.
+ *   You may obtain a copy of the License at
+ *
+ *       http://www.apache.org/licenses/LICENSE-2.0
+ *
+ *   Unless required by applicable law or agreed to in writing, software
+ *   distributed under the License is distributed on an "AS IS" BASIS,
+ *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *   See the License for the specific language governing permissions and
+ *   limitations under the License.
+ ****************************************************************************/
 
 #include <QCommandLineParser>
 #include <QFile>
@@ -64,7 +66,7 @@ public:
     bool processNextPhase();
     void setLocale();
     void setService(const QString &service, bool enabled);
-    void writeKeyFile();
+    bool writeKeyFile();
 
     bool INSTALL_FROM_ROOT_DEVICE;
     bool POPULATE_MEDIA_MOUNTPOINTS;
@@ -96,7 +98,6 @@ private slots:
     void on_pushSetKeyboard_clicked();
     void on_pushClose_clicked();
     void on_pushNext_clicked();
-    void on_checkShowPass_stateChanged(int);
     void on_pushPartReload_clicked();
     void on_pushRunPartMan_clicked();
     void on_pushServices_clicked();
@@ -104,17 +105,8 @@ private slots:
     void on_comboDisk_currentIndexChanged(int);
     void on_sliderPart_sliderPressed();
     void on_sliderPart_valueChanged(int value);
-    void on_checkEncryptAuto_toggled(bool checked);
-    void on_radioCustomPart_clicked(bool checked);
-
-    void on_pushLoadKey_clicked();
-    void on_pushBenchmarkCrypto_clicked();
-    void on_pushAdvancedCrypto_clicked();
-    void on_pushAdvancedCryptoCust_clicked();
-    void on_comboCryptoCipher_currentIndexChanged(const QString &arg1);
-    void on_comboCryptoChain_currentIndexChanged(const QString &arg1);
-    void on_spinCryptoKeySize_valueChanged(int i);
-    void on_comboCryptoIVGen_currentIndexChanged(const QString &arg1);
+    void on_boxEncryptAuto_toggled(bool checked);
+    void on_radioCustomPart_toggled(bool checked);
 
     void on_radioBootMBR_toggled();
     void on_radioBootPBR_toggled();
@@ -147,7 +139,7 @@ private:
     bool isRemasteredDemoPresent = false;
 
     // source medium
-    QString rootSources;
+    QStringList rootSources;
     QString bootSource;
 
     // auto-mount setup
@@ -170,17 +162,6 @@ private:
     bool haveSnapshotUserAccounts = false;
     bool haveOldHome = false;
 
-    // Advanced Encryption Settings page
-    int ixPageRefAdvancedFDE = 0;
-    int indexCryptoCipher;
-    int indexCryptoChain;
-    int indexCryptoIVGen;
-    int indexCryptoIVHash;
-    int iCryptoKeySize;
-    int indexCryptoHash;
-    int indexCryptoRandom;
-    int iCryptoRoundTime;
-
     // cached time zone list
     QStringList listTimeZones;
 
@@ -201,7 +182,6 @@ private:
     void failUI(const QString &msg);
     void manageConfig(enum ConfigAction mode);
     void stashServices(bool save);
-    void stashAdvancedFDE(bool save);
     int selectTimeZone(const QString &zone);
     void rsynchomefolder(const QString dpath);
     void changeRemasterdemoToNewUser(const QString dpath);
